.. _release-0-8-1:

0.8.1
=====

Bokeh ``0.8.1``  (Feb 2015) is focused on stability, bug fixes and improved
documentation.

* Fixed HoverTool
* Fixed Abstract rendering implementation and docs
* Fixed chart gallery and docs
* Removed leftovers from the old plotting API implementation
* Some other minor docs fixes
